/*
HDD Explorer Script Generator 
Copyright (c) 2006 Bruno Freitas
bootsector@ig.com.br
 
Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
of the Software, and to permit persons to whom the Software is furnished to do
so, subject to the following conditions:
 
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
 
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/

import java.io.*;
import java.util.*;

public class Aplicacao implements Serializable {
    private String titulo, autor, descricao, executavel, diretorio;
    private Vector<String> arquivos;
    
    public Aplicacao() {
        arquivos = new Vector<String>();
        titulo = autor = descricao = executavel = diretorio = "";
    }
    
    public void setTitulo(String titulo) {
        if (titulo.length() > 127)
            titulo = titulo.substring(0, 127);
        
        this.titulo = titulo;
    }
    
    public String getTitulo() {
        return titulo;
    }
    
    public void setAutor(String autor) {
        if (autor.length() > 31)
            autor = autor.substring(0, 31);
        
        this.autor = autor;
    }
    
    public String getAutor() {
        return autor;
    }
    
    public void setDescricao(String descricao) {
        if (descricao.length() > 1023)
            descricao = descricao.substring(0, 1023);
        
        descricao = descricao.replace("\\n", "\n");
        
        this.descricao = descricao;
    }
    
    public String getDescricao() {
        return descricao;
    }
    
    public void setExecutavel(String executavel) {
        if (executavel.length() > 127)
            executavel = executavel.substring(0, 127);
        
        this.executavel = executavel;
    }
    
    public String getExecutavel() {
        return executavel;
    }
    
    public void setDiretorio(String diretorio) {
        this.diretorio = diretorio;
    }
    
    public String getDiretorio() {
        return diretorio;
    }
    
    public int getTotalArquivos() {
        return arquivos.size();
    }
    
    public void adicionaArquivo(String nome) {
        // Verifica por nome de arquivo, no o caminho inteiro, pois todos
        // ficaro num nico diretorio no final da gerao da estrutura.
        
        String tmp = nome.substring(nome.lastIndexOf(File.separatorChar)+1);
        
        for(int i = 0; i < arquivos.size(); i++) {
            String n = (String) arquivos.elementAt(i);
            n = n.substring(n.lastIndexOf(File.separatorChar)+1);
            if (n.compareToIgnoreCase(tmp) == 0)
                return;
        }
        
        arquivos.add(nome);
    }
    
    public void removeArquivo(int indice) {
        if (arquivos.isEmpty() || indice < 0 || indice > (arquivos.size()-1))
            return;
        
        arquivos.remove(indice);
    }
    
    public String getArquivo(int indice) {
        if (arquivos.isEmpty() || indice < 0 || indice > (arquivos.size()-1))
            return "";
        
        return arquivos.elementAt(indice);
    }
    
    public String toString() {
        return titulo;
    }
}
